@@ -37,7 +37,7 @@ ff_league.sleeper_conn <- function(conn) {
     qb_type = .sleeper_qbtype(starting_positions)$type,
     idp = .sleeper_isidp(starting_positions),
     scoring_flags = .sleeper_flag_scoring(scoring_settings),
-    best_ball = FALSE,
+    best_ball = .sleeper_isbestball(league_endpoint),
     salary_cap = FALSE,
     player_copies = 1,
     years_active = .sleeper_history(league_endpoint)$season,
@@ -48,6 +48,15 @@ ff_league.sleeper_conn <- function(conn) {
   )
 }
 
+.sleeper_isbestball <- function(league_endpoint){
+
+  x <- league_endpoint$settings[["best_ball"]]
+
+  if(!is.null(x) && as.logical(x)) return(TRUE)
+
+  return(FALSE)
+}
+
 .sleeper_isdyno <- function(league_endpoint) {
   switch(as.character(league_endpoint$settings$type),
     "2" = "dynasty",
@@ -125,7 +134,7 @@ ff_league.sleeper_conn <- function(conn) {
 
   prev <- league_endpoint$previous_league_id
 
-  while (prev != "0") {
+  while (!is.null(prev) && prev != "0") {
     prev_endpoint <- glue::glue("league/{prev}") %>%
       sleeper_getendpoint() %>%
       purrr::pluck("content")
