@@ -11,10 +11,10 @@ eval <- TRUE
 
 tryCatch(expr = {
   
-  download.file("https://github.com/dynastyprocess/ffscrapr-tests/archive/1.4.3.zip","f.zip")
+  download.file("https://github.com/ffverse/ffscrapr-tests/archive/1.4.4.zip","f.zip")
   unzip('f.zip', exdir = ".")
   
-  httptest::.mockPaths(new = "ffscrapr-tests-1.4.3")},
+  httptest::.mockPaths(new = "ffscrapr-tests-1.4.4")},
   warning = function(e) eval <<- FALSE,
   error = function(e) eval <<- FALSE)
 
@@ -100,5 +100,5 @@ age_summary
 ## ----include = FALSE----------------------------------------------------------
 httptest::stop_mocking()
 
-unlink(c("ffscrapr-tests-1.4.3","f.zip"), recursive = TRUE, force = TRUE)
+unlink(c("ffscrapr-tests-1.4.4","f.zip"), recursive = TRUE, force = TRUE)
 
