@@ -10,6 +10,10 @@ with_mock_api({
     jml_league <- ff_league(jml_conn)
     expect_tibble(jml_league, any.missing = FALSE, min.rows = 1)
 
+    bestball_conn <- ff_connect(platform = "sleeper", league_id = "711961723149553664", season = 2021)
+    bestball_league <- ff_league(bestball_conn)
+    expect_tibble(bestball_league, any.missing = FALSE, min.rows = 1)
+
     got_conn <- fleaflicker_connect(2020, 206154)
     got_league <- ff_league(got_conn)
     expect_tibble(got_league, min.rows = 1)
