@@ -4,9 +4,9 @@ with_mock_api({
 
     if (!identical(Sys.getenv("MOCK_BYPASS"), "true")) {
       testthat::local_mock(
-        nflfastr_weekly = function() readRDS("ffscrapr-tests-1.4.3/gh_nflfastr/player_stats.rds"),
+        nflfastr_weekly = function() readRDS("ffscrapr-tests-1.4.4/gh_nflfastr/player_stats.rds"),
         nflfastr_rosters = function(seasons) {
-          purrr::map_df(seasons, ~ readRDS(glue::glue("ffscrapr-tests-1.4.3/gh_nflfastr/roster_{.x}.rds")))
+          purrr::map_df(seasons, ~ readRDS(glue::glue("ffscrapr-tests-1.4.4/gh_nflfastr/roster_{.x}.rds")))
         }
       )
     }
@@ -15,6 +15,11 @@ with_mock_api({
     sfb_scoringhistory <- ff_scoringhistory(sfb_conn, 2019:2020)
     expect_tibble(sfb_scoringhistory, min.rows = 6000)
 
+    foureight_conn <- mfl_connect(2020, 22627)
+    foureight_scoringhistory <- ff_scoringhistory(foureight_conn, 2019:2020)
+    expect_tibble(foureight_scoringhistory, min.rows = 6000)
+    expect_lt(max(foureight_scoringhistory$points),60)
+
     jml_conn <- ff_connect(platform = "sleeper", league_id = "522458773317046272", season = 2020)
     jml_scoringhistory <- ff_scoringhistory(jml_conn, 2019:2020)
     expect_tibble(jml_scoringhistory, min.rows = 6000)
